@@ -101,6 +101,8 @@ default_settings = dict(
                 definition='Can user self change their email'),
     A2_PROFILE_CAN_EDIT_PROFILE = Setting(default=True,
                 definition='Can user self edit their profile'),
+    A2_PROFILE_CAN_MANAGE_FEDERATION = Setting(default=True,
+                definition='Can user manage its federations'),
     A2_HOMEPAGE_URL = Setting(default=None, definition='IdP has no homepage, '
         'redirect to this one.'),
     A2_CAN_RESET_PASSWORD = Setting(default=True, definition='Allow online reset of passwords'),
