@@ -1212,10 +1212,10 @@ ATTRIBUTE_MAPPING = {
 },
 
 #Extracted from openldap schema /etc/ldap/schema/core.ldif
-"gn": {
+"givenName": {
     "oid": "2.5.4.42",
     "display_name": _("First name") + "(gn givenName)",
-    "alias": ['givenName'],
+    "alias": ['gn'],
     "profile_field_name": 'first_name',
     "type": "http://www.w3.org/2001/XMLSchema#string",
     "namespaces": {
@@ -2280,6 +2280,31 @@ ATTRIBUTE_MAPPING = {
     "syntax": "1.3.6.1.4.1.1466.115.121.1.15{128}",
 },
 
+#SupAnn version 2009.6
+#http://www.cru.fr/_media/documentation/supann/supann_2009.schema.txt
+"mailForwardingAddress": {
+    "oid": "2.16.840.1.113730.3.1.17",
+    "display_name": "mailForwardingAddress",
+    "type": "http://www.w3.org/2001/XMLSchema#string",
+    "syntax": "1.3.6.1.4.1.1466.115.121.1.15{128}",
+},
+
+# macedir.org for eduGain
+"schacHomeOrganization": {
+        "oid": "1.3.6.1.4.1.25178.1.2.9",
+        "display_name": "The persons home organization using the domain of the organization",
+        "type": "http://www.w3.org/2001/XMLSchema#string",
+        "syntax": "1.3.6.1.4.1.1466.115.121.1.15",
+},
+
+# macedir .org or eduGain
+"schacHomeOrganizationType": {
+        "oid": "1.3.6.1.4.1.25178.1.2.10",
+        "display_name": "Identifies the type of organisation specified in the person's schacHomeOrganization attribute.",
+        "type": "http://www.w3.org/2001/XMLSchema#string",
+        "syntax": "1.3.6.1.4.1.1466.115.121.1.15",
+},
+
 "role": {
     "oid": "1.3.6.1.4.1.36560.42.1",
     "display_name": "Role",
