@@ -95,7 +95,7 @@ _DEFAULTS = {
     # Conserve the passsword in the Django User object
     'keep_password': True,
     # Only authenticate users coming from the corresponding realm
-    'limit_to_realm': True,
+    'limit_to_realm': False,
     # Assign users mandatorily to some groups
     'set_mandatory_groups': (),
 }
@@ -276,25 +276,27 @@ class LDAPBackend(object):
                 if isinstance(block[i], basestring):
                     block[i] = (block[i],)
             # lowercase LDAP attribute names
+            block['external_id_tuples'] = map(lambda t: map(str.lower, map(str, t)), block['external_id_tuples'])
+            block['attribute_mappings'] = map(lambda t: map(str.lower, map(str, t)), block['attribute_mappings'])
             for key in _TO_LOWERCASE:
                 # we handle strings, list of strings and list of list or tuple whose first element is a string
                 if isinstance(block[key], basestring):
-                    block[key] = block[key].lower()
+                    block[key] = str(block[key]).lower()
                 elif isinstance(block[key], (list, tuple)):
                     new_seq = []
                     for elt in block[key]:
                         if isinstance(elt, basestring):
-                            elt = elt.lower()
+                            elt = str(elt).lower()
                         elif isinstance(elt, (list, tuple)):
                             elt = list(elt)
-                            elt[0] = elt[0].lower()
+                            elt[0] = str(elt[0]).lower()
                             elt = tuple(elt)
                         new_seq.append(elt)
                     block[key] = tuple(new_seq)
                 elif isinstance(block[key], dict):
                     newdict = {}
                     for subkey in block[key]:
-                        newdict[subkey.lower()] = block[subkey]
+                        newdict[str(subkey).lower()] = block[key][subkey]
                     block[key] = newdict
                 else:
                     raise NotImplementedError('LDAP setting %r cannot be '
@@ -359,7 +361,10 @@ class LDAPBackend(object):
                             authz_ids.append(utf8_username)
                         elif block['user_filter']:
                             try:
-                                query = filter_format(block['user_filter'], (utf8_username,))
+                                # allow multiple occurences of the username in the filter
+                                user_filter = block['user_filter']
+                                n = len(user_filter.split('%s')) - 1
+                                query = filter_format(user_filter, (utf8_username,) * n)
                             except TypeError, e:
                                 log.error('user_filter syntax error %r: %s',
                                         block['user_filter'], e)
@@ -602,6 +607,8 @@ class LDAPBackend(object):
         for external_id_tuple in block['external_id_tuples']:
             attributes.update(cls.attribute_name_from_external_id_tuple(
                 external_id_tuple))
+        for from_at, to_at in block['attribute_mappings']:
+            attributes.add(to_at)
         return set(map(str.lower, map(str, attributes)))
 
     @classmethod
