@@ -1,14 +1,18 @@
 from optparse import make_option
 import sys
 import xml.etree.ElementTree as etree
+import os
 
 import lasso
 from django.core.management.base import BaseCommand, CommandError
 from django.db import transaction
 from django.template.defaultfilters import slugify
+from django.utils.translation import gettext as _
 
 from authentic2.saml.models import *
-
+from authentic2.saml.shibboleth.afp_parser import parse_attribute_filters_file
+from authentic2.attribute_aggregator.core import (get_definition_from_alias,
+        get_full_definition, get_def_name_from_alias)
 
 SAML2_METADATA_UI_HREF = 'urn:oasis:names:tc:SAML:metadata:ui'
 
@@ -31,13 +35,34 @@ DISPLAY_NAME = mdui_element_name('DisplayName')
 ENTITY_ID = 'entityID'
 PROTOCOL_SUPPORT_ENUMERATION = 'protocolSupportEnumeration'
 
+def build_saml_attribute_kwargs(provider, name):
+    '''Build SAML attribute following the LDAP profile'''
+    content_type = ContentType.objects.get_for_model(LibertyProvider)
+    object_id = provider.pk
+    attribute_name = name
+    definition = get_full_definition(name)
+    if not definition:
+        definition = get_definition_from_alias(name)
+        attribute_name = get_def_name_from_alias(name)
+    if not definition:
+        return {}, None
+    oid = definition['oid']
+    return {
+        'content_type': content_type,
+        'object_id': object_id,
+        'name_format': 'uri',
+        'friendly_name': name,
+        'name': 'urn:oid:%s' % oid,
+    }, attribute_name
+
 def check_support_saml2(tree):
     if tree is not None and lasso.SAML2_PROTOCOL_HREF in tree.get(PROTOCOL_SUPPORT_ENUMERATION):
         return True
     return False
 
-def load_one_entity(tree, options, sp_policy=None, idp_policy=None):
+def load_one_entity(tree, options, sp_policy=None, idp_policy=None, afp=None):
     '''Load or update an EntityDescriptor into the database'''
+    verbosity = int(options['verbosity'])
     entity_id = tree.get(ENTITY_ID)
     name = None
     # try mdui nodes
@@ -77,7 +102,7 @@ def load_one_entity(tree, options, sp_policy=None, idp_policy=None):
         # get or create the provider
         provider, created = LibertyProvider.objects.get_or_create(entity_id=entity_id,
                 protocol_conformance=3, defaults={'name': name, 'slug': slug})
-        if options['verbosity'] == '2':
+        if verbosity > '1':
             if created:
                 what = 'Creating'
             else:
@@ -92,18 +117,44 @@ def load_one_entity(tree, options, sp_policy=None, idp_policy=None):
         options['count'] = options.get('count', 0) + 1
         if idp:
             identity_provider, created = LibertyIdentityProvider.objects.get_or_create(
-                    liberty_provider=provider)
-            identity_provider.enabled = True
+                    liberty_provider=provider,
+                    defaults={'enabled': not options['create-disabled']})
             if idp_policy:
                 identity_provider.idp_options_policy = idp_policy
             identity_provider.save()
         if sp:
             service_provider, created = LibertyServiceProvider.objects.get_or_create(
-                    liberty_provider=provider)
-            service_provider.enabled = True
+                    liberty_provider=provider,
+                    defaults={'enabled': not options['create-disabled']})
             if sp_policy:
                 service_provider.sp_options_policy = sp_policy
             service_provider.save()
+        if afp and provider.entity_id in afp:
+            pks = []
+            for name in afp[provider.entity_id]:
+                kwargs, attribute_name = build_saml_attribute_kwargs(provider, name)
+                if not kwargs:
+                    if verbosity > 1:
+                        print >>sys.stderr, _('Unable to find an LDAP definition for attribute %s on %s') % (name, provider)
+                    continue
+                attribute_name = attribute_name.lower()
+                defaults = {
+                    'attribute_name': attribute_name,
+                }
+                # create object with default attribute mapping to the same name
+                # as the attribute if no SAMLAttribute model already exists,
+                # otherwise do nothing
+                try:
+                    attribute, created = SAMLAttribute.objects.get_or_create(defaults=defaults,
+                            **kwargs)
+                    if created and verbosity > 1:
+                        print _('Created new attribute %s for %s') % (name, provider)
+                    pks.append(attribute.pk)
+                except SAMLAttribute.MultipleObjectsReturned:
+                    pks.extend(SAMLAttribute.objects.filter(**kwargs).values_list('pk', flat=True))
+            if options.get('reset-attributes'):
+                # remove attributes not matching the filters
+                SAMLAttribute.objects.for_generic_object(provider).exclude(pk__in=pks).delete()
 
 class Command(BaseCommand):
     '''Load SAMLv2 metadata file into the LibertyProvider, LibertyServiceProvider
@@ -146,12 +197,42 @@ class Command(BaseCommand):
             help='Tag the loaded providers with the given source string, \
 existing providers with the same tag will be removed if they do not exist\
  anymore in the metadata file.'),
+        make_option('--reset-attributes',
+            action='store_true',
+            default=False,
+            help='When loading shibboleth attribute filter policies, start by '
+                 'removing all existing SAML attributes for each provider'),
+        make_option('--shibboleth-attribute-filter-policy',
+            dest='attribute-filter-policy',
+            default=None,
+            help='''Path to a file containing an Attribute Filter Policy for the
+Shibboleth IdP, that will be used to configure SAML attributes for
+each provider. The following schema is supported:
+
+    <AttributeFilterPolicy id="<whatever>">
+        <PolicyRequirementRule xsi:type="basic:AttributeRequesterString" value="<entityID>" >
+        [
+          <AttributeRule attributeID="<attribute-name>">
+                <PermitValueRule xsi:type="basic:ANY"/>
+          </AttributeRule>
+        ]*
+    </AttributeFilterPolicy>
+
+Any other kind of attribute filter policy is unsupported.
+'''),
+        make_option('--create-disabled',
+            dest='create-disabled',
+            action='store_true',
+            default=False,
+            help='When creating a new provider, make it disabled by default.'),
         )
+
     args = '<metadata_file>'
     help = 'Load the specified SAMLv2 metadata file'
 
     @transaction.commit_manually
     def handle(self, *args, **options):
+        verbosity = int(options['verbosity'])
         source = options['source']
         try:
             if not args:
@@ -173,28 +254,44 @@ existing providers with the same tag will be removed if they do not exist\
             if doc.getroot().tag == ENTITY_DESCRIPTOR_TN:
                 load_one_entity(doc.getroot(), options)
             elif doc.getroot().tag == ENTITIES_DESCRIPTOR_TN:
+                afp = None
+                if 'attribute-filter-policy' in options and options['attribute-filter-policy']:
+                    path = options['attribute-filter-policy']
+                    if not os.path.isfile(path):
+                        raise CommandError(
+                            'No attribute filter policy file %s' % path)
+                    afp = parse_attribute_filters_file(
+                        options['attribute-filter-policy'])
                 sp_policy = None
                 if 'sp_policy' in options and options['sp_policy']:
                     sp_policy_name = options['sp_policy']
                     try:
                         sp_policy = SPOptionsIdPPolicy.objects.get(name=sp_policy_name)
-                        print 'Service providers are set with the following SAML2 \
-                            options policy: %s' % sp_policy
+                        if verbosity > 1:
+                            print 'Service providers are set with the following SAML2 \
+                                options policy: %s' % sp_policy
                     except:
-                        print 'SAML2 service provider options policy with name %s not found' % sp_policy_name
+                        if verbosity > 0:
+                            print >>sys.stderr, _('SAML2 service provider options policy with name %s not found') % sp_policy_name
+                            raise CommandError()
                 else:
-                    print 'No SAML2 service provider options policy provided'
+                    if verbosity > 1:
+                        print 'No SAML2 service provider options policy provided'
                 idp_policy = None
                 if 'idp_policy' in options and options['idp_policy']:
                     idp_policy_name = options['idp_policy']
                     try:
                         idp_policy = IdPOptionsSPPolicy.objects.get(name=idp_policy_name)
-                        print 'Identity providers are set with the following SAML2 \
-                            options policy: %s' % idp_policy
+                        if verbosity > 1:
+                            print 'Identity providers are set with the following SAML2 \
+                                options policy: %s' % idp_policy
                     except:
-                        print 'SAML2 identity provider options policy with name %s not found' % idp_policy_name
+                        if verbosity > 0:
+                            print >>sys.stderr, _('SAML2 identity provider options policy with name %s not found') % idp_policy_name
+                            raise CommandError()
                 else:
-                    print 'No SAML2 identity provider options policy provided'
+                    if verbosity > 1:
+                        print _('No SAML2 identity provider options policy provided')
                 loaded = []
                 if doc.getroot().tag == ENTITY_DESCRIPTOR_TN:
                     entity_descriptors = [ doc.getroot() ]
@@ -202,15 +299,16 @@ existing providers with the same tag will be removed if they do not exist\
                     entity_descriptors = doc.getroot().findall(ENTITY_DESCRIPTOR_TN)
                 for entity_descriptor in entity_descriptors:
                     try:
-                        load_one_entity(entity_descriptor, options, sp_policy=sp_policy, idp_policy=idp_policy)
+                        load_one_entity(entity_descriptor, options,
+                                sp_policy=sp_policy, idp_policy=idp_policy,
+                                afp=afp)
                         loaded.append(entity_descriptor.get(ENTITY_ID))
                     except Exception, e:
-                        raise
-                        entity_id = entity_descriptor.get(ENTITY_ID)
-                        if options['ignore-errors']:
-                            print >> sys.stderr, 'Unable to load EntityDescriptor for %s: %s' % (entity_id, str(e))
-                        else:
-                            raise CommandError('EntityDescriptor loading: %s' % str(e))
+                        if not options['ignore-errors']:
+                            raise
+                        if verbosity > 0:
+                            print >>sys.stderr, _('Failed to load entity descriptor for %s') % entity_descriptor.get(ENTITY_ID)
+                        raise CommandError()
                 if options['source']:
                     if options['delete']:
                         print 'Finally delete all providers for source: %s...' % source
@@ -219,7 +317,8 @@ existing providers with the same tag will be removed if they do not exist\
                         to_delete = LibertyProvider.objects.filter(federation_source=source)\
                                 .exclude(entity_id__in=loaded)
                         for provider in to_delete:
-                            print 'Delete obsolete provider %s' % provider.entity_id
+                            if verbosity > 1:
+                                print _('Deleted obsolete provider %s') % provider.entity_id
                             provider.delete()
             else:
                 raise CommandError('%s is not a SAMLv2 metadata file' % metadata_file)
@@ -229,4 +328,5 @@ existing providers with the same tag will be removed if they do not exist\
         else:
             transaction.commit()
         if not options.get('delete'):
-            print 'Loaded', options.get('count', 0), 'providers'
+            if verbosity > 1:
+                print 'Loaded', options.get('count', 0), 'providers'
