@@ -337,6 +337,7 @@ class SAMLAttribute(models.Model):
     ATTRIBUTE_NAME_FORMATS = (
             ('basic', 'Basic'),
             ('uri', 'URI'),
+            ('unspecified', 'Unspecified'),
     )
     objects = managers.SAMLAttributeManager()
 
@@ -351,7 +352,7 @@ class SAMLAttribute(models.Model):
             default='basic',
             choices=ATTRIBUTE_NAME_FORMATS)
     name = models.CharField(
-            max_length=64,
+            max_length=128,
             verbose_name=_('name'),
             blank=True,
             help_text=_('the local attribute name is used if left blank'))
@@ -361,6 +362,10 @@ class SAMLAttribute(models.Model):
             blank=True)
     attribute_name = models.CharField(max_length=64,
             verbose_name=_('attribute name'))
+    enabled = models.BooleanField(
+            verbose_name=_('enabled'),
+            default=True,
+            blank=True)
 
     def clean(self):
         super(SAMLAttribute, self).clean()
@@ -370,8 +375,10 @@ class SAMLAttribute(models.Model):
     def name_format_uri(self):
         if self.name_format == 'basic':
             return lasso.SAML2_ATTRIBUTE_NAME_FORMAT_BASIC
-        elif self.name.format == 'uri':
+        elif self.name_format == 'uri':
             return lasso.SAML2_ATTRIBUTE_NAME_FORMAT_URI
+        elif self.name_format == 'unspecified':
+            return lasso.SAML2_ATTRIBUTE_NAME_FORMAT_UNSPECIFIED
         else:
             raise NotImplementedError
 
@@ -473,6 +480,8 @@ class LibertyProvider(models.Model):
     ca_cert_chain = models.TextField(blank=True)
     federation_source = models.CharField(max_length=64, blank=True, null=True)
 
+    attributes = GenericRelation(SAMLAttribute)
+
     objects = managers.LibertyProviderManager()
 
     def __unicode__(self):
@@ -534,6 +543,10 @@ class LibertyServiceProvider(models.Model):
     attribute_policy = models.ForeignKey('idp.AttributePolicy',
              related_name = "attribute_policy",
             verbose_name=_("attribute policy"), null=True, blank=True)
+    users_can_manage_federations = models.BooleanField(
+            verbose_name=_('users can manage federation'),
+            default=True,
+            blank=True)
 
     objects = managers.GetByLibertyProviderManager()
 
